carrot.serialization — Carrot v0.5.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.5.0 documentation »
- API Reference »

# carrot.serialization

Centralized support for encoding/decoding of data structures. Requires a json library (cjson, simplejson, or Python 2.6+).

Optionally installs support for `Hessian 1.0` and `YAML` if the necessary libraries are installed (HessianPy and PyYAML, respectively).

exception `carrot.serialization.` `SerializerNotInstalled`
  Support for the requested serialization type is not installed

`carrot.serialization.` `registry`
  `carrot.serialization.` `encode`(data, serializer=default_serializer)

  Encode data using the registry’s default encoder.

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.5.0 documentation »
- API Reference »